@@ -187,6 +187,7 @@ var app = new Vue({
     el: '#app',
     data: {
         formInline: {},
+        hasLoadCache: false,
         layer: {
             visible: false,
             title: '弹出层',
@@ -413,7 +414,7 @@ var app = new Vue({
                 this.onSubmit();
             });
         },
-        refreshData: function () {
+        reset() {
             this.search = JSON.parse(JSON.stringify(this.backupSearch));
             this.$nextTick(function () {
                 //把储存的数据删掉
@@ -424,6 +425,10 @@ var app = new Vue({
                 this.toolbars.isActive = true;
             });
         },
+        refreshData: function () {
+            console.log('refreshData');
+            this.onSubmit();
+        },
         add: function (title) {
             if (window.SIMPLEAPI && window.SIMPLEAPI.toolbar) {
                 var rs = window.SIMPLEAPI.toolbar.call({}, 'add', this);
@@ -466,24 +471,41 @@ var app = new Vue({
             this.table.selection = selection;
             this.toolbars.isActive = selection.length <= 0;
         },
+        encodeValue(value) {
+            return encodeURIComponent(value);
+        },
+        isDateRange(field){
+            for(let key in this.search.filters){
+                if(key === field+"__gte" || key === field+"__lte"){
+                    return true;
+                }
+            }
+            return false;
+        },
         exports: function (btn, key) {
             //设置url
             let url = window.location.href;
 
             let params = [];
             for (let key in this.search.filters) {
+                if(this.isDateRange(key)){
+                    continue
+                }
                 let value = this.search.filters[key];
-                params.push(`${key}=${value}`);
+                params.push(`${key}=${this.encodeValue(value)}`);
             }
 
             let paramsString = params.join('&');
 
-            if (url.indexOf('?') == -1) {
+            if (url.indexOf('?') === -1) {
                 url += '?';
             }
             url += paramsString;
+            // console.log(url);
             this.form.exportAction = url;
-            document.getElementById('export_form').submit()
+            this.$nextTick(()=>{
+                document.getElementById('export_form').submit()
+            })
         },
         go_url: function (url, icon, name) {
             if (parent.app.openTab) {
@@ -503,46 +525,46 @@ var app = new Vue({
                 self.layer.loading = true;
                 self.layer.visible = true;
 
-                  //开始提交
-            let formData = new FormData();
-            //方法名
-            formData.append('_action', action);
+                //开始提交
+                let formData = new FormData();
+                //方法名
+                formData.append('_action', action);
 
-            //如果是选中全部的情况下，带搜索条件过去
-            if (self.search.all == 1) {
-                formData.append('_search', self.search.search);
-                //filter需要过滤数据
-                let filter = {};
-                for (let key in self.search.filters) {
-                    if (self.search.filters[key] !== '') {
-                        filter[key] = self.search.filters[key];
+                //如果是选中全部的情况下，带搜索条件过去
+                if (self.search.all == 1) {
+                    formData.append('_search', self.search.search);
+                    //filter需要过滤数据
+                    let filter = {};
+                    for (let key in self.search.filters) {
+                        if (self.search.filters[key] !== '') {
+                            filter[key] = self.search.filters[key];
+                        }
+                    }
+
+                    formData.append('_filter', JSON.stringify(filter));
+                } else {
+                    let selected = [];
+                    self.table.selection.forEach(item => selected.push(item._id));
+                    formData.append('_selected', selected.join(','));
+                }
+
+
+                formData.append('select_across', self.search.all);
+                //获取选中的数据
+
+                formData.append('csrfmiddlewaretoken', document.querySelector('[name="csrfmiddlewaretoken"]').value);
+
+                //获取表单数据
+                for (let key in self.layer.form) {
+                    let value = self.layer.form[key];
+                    if (value) {
+                        formData.append(key, value);
                     }
                 }
 
-                formData.append('_filter', JSON.stringify(filter));
-            } else {
-                let selected = [];
-                self.table.selection.forEach(item => selected.push(item._id));
-                formData.append('_selected', selected.join(','));
-            }
-
-
-            formData.append('select_across', self.search.all);
-            //获取选中的数据
-
-            formData.append('csrfmiddlewaretoken', document.querySelector('[name="csrfmiddlewaretoken"]').value);
-
-            //获取表单数据
-            for (let key in self.layer.form) {
-                let value = self.layer.form[key];
-                if (value) {
-                    formData.append(key, value);
-                }
-            }
-
-            axios.post(`${layer.url}`,formData).then(res => {
-                self.showLayer(action, res.data);
-            }).finally(() => self.layer.loading = false);
+                axios.post(`${layer.url}`, formData).then(res => {
+                    self.showLayer(action, res.data);
+                }).finally(() => self.layer.loading = false);
 
             } else {
                 this.showLayer(action, layer);
@@ -726,13 +748,14 @@ var app = new Vue({
             }
         },
         deleteData: function (id) {
+            var self = this;
+            //获取查询参数
             if (window.SIMPLEAPI && window.SIMPLEAPI.toolbar) {
                 var rs = window.SIMPLEAPI.toolbar.call({}, 'delete', this);
                 if (!rs) {
                     return;
                 }
             }
-            var self = this;
 
             var target = self;
 
@@ -764,6 +787,8 @@ var app = new Vue({
                 if (self.search.all == 1) {
                     delete ds['ids'];
                     ds['all'] = 1;
+                    ds['filters'] = self.search.filters;
+                    ds['search'] = self.search.search;
                 }
 
                 post(ds, self).then(res => {
@@ -885,23 +910,40 @@ var app = new Vue({
                         self[item] = data[item];
                     }
                 }
+                this.$nextTick(() => {
+                    this.hasLoadCache = true;
+                })
             }
             this.onSubmit();
         });
-
+        //监听子页面的消息
+        window.addEventListener('message', function (e) {
+            console.log(e.data);
+            if (e.data.type === 'refresh') {
+                self.refreshData();
+            } else if (e.data.type === 'close') {
+                if (window.currentModal) {
+                    window.currentModal.close();
+                } else {
+                    console.warn('没有找到当前的modal对话框，无法关闭');
+                }
+            }
+        });
     },
     updated() {
-        // console.log('updated')
-        //将数据存到sessionStore，下次打开失效
-        if (sessionStorage) {
-            //克隆
-            var clone = JSON.parse(JSON.stringify(this.search));
-            //刷新页面的时候，要更新toolbars
-            clone.initialized = false;
-            sessionStorage[this.cacheKey] = JSON.stringify({
-                //只缓存搜索，会减少故障几率
-                search: clone
-            });
+        if (this.hasLoadCache) {
+            console.log('updated')
+            //将数据存到sessionStore，下次打开失效
+            if (sessionStorage) {
+                //克隆
+                var clone = JSON.parse(JSON.stringify(this.search));
+                //刷新页面的时候，要更新toolbars
+                clone.initialized = false;
+                sessionStorage[this.cacheKey] = JSON.stringify({
+                    //只缓存搜索，会减少故障几率
+                    search: clone
+                });
+            }
         }
     }
 });
\ No newline at end of file
